@@ -48,7 +48,8 @@ def onnx_node_attributes_to_dict(args):
 
 
 def onnx_to_keras(onnx_model, input_names,
-                  input_shapes=None, name_policy=None, verbose=True, change_ordering=False):
+                  input_shapes=None, name_policy=None, verbose=True, change_ordering=False,
+                  input_types=None):
     """
     Convert ONNX graph to Keras model format
     :param onnx_model: loaded ONNX model
@@ -117,11 +118,10 @@ def onnx_to_keras(onnx_model, input_names,
                     input_shape = input_shapes[i]
                 else:
                     input_shape = [i.dim_value for i in onnx_i.type.tensor_type.shape.dim][1:]
-
+                dtype = None if input_types is None else input_types[i]
                 layers[input_name] = keras.layers.InputLayer(
-                    input_shape=input_shape, name=input_name
+                    input_shape=input_shape, name=input_name, dtype=dtype
                 ).output
-
                 keras_inputs.append(layers[input_name])
 
                 logger.debug('Found input {0} with shape {1}'.format(input_name, input_shape))
@@ -193,6 +193,8 @@ def onnx_to_keras(onnx_model, input_names,
 
                 if node_input in weights:
                     logger.debug('Found in weights, add as a numpy constant.')
+                    if node_type == "Gather":
+                        node_params['is_embedding'] = True
                     layers[node_input] = weights[node_input]
                 else:
                     raise AttributeError('Current node is not in weights / model inputs / layers.')
