@@ -3,12 +3,12 @@ from .activation_layers import convert_relu, convert_elu, convert_lrelu, convert
     convert_sigmoid, convert_tanh, convert_softmax, convert_prelu, convert_hard_sigmoid, convert_erf
 from .operation_layers import convert_clip, convert_exp, convert_reduce_sum, convert_reduce_mean, \
     convert_log, convert_pow, convert_sqrt, convert_split, convert_cast, convert_floor, convert_identity, \
-    convert_argmax, convert_reduce_l2, convert_reduce_max
+    convert_argmax, convert_reduce_l2, convert_reduce_max, convert_reciprocal
 from .elementwise_layers import convert_elementwise_div, convert_elementwise_add, convert_elementwise_mul, \
     convert_elementwise_sub, convert_max, convert_min, convert_mean
 from .linear_layers import convert_gemm
 from .reshape_layers import convert_transpose, convert_shape, convert_gather, convert_unsqueeze, \
-    convert_concat, convert_reshape, convert_flatten, convert_slice, convert_squeeze, convert_expand
+    convert_concat, convert_reshape, convert_flatten, convert_slice, convert_squeeze, convert_expand, convert_resize
 from .constant_layers import convert_constant
 from .normalization_layers import convert_batchnorm, convert_instancenorm, convert_dropout, convert_lrn
 from .pooling_layers import convert_avgpool, convert_maxpool, convert_global_avg_pool
@@ -21,6 +21,7 @@ AVAILABLE_CONVERTERS = {
     'Conv': convert_conv,
     'ConvTranspose': convert_convtranspose,
     'Relu': convert_relu,
+    'Resize': convert_resize,
     'Elu': convert_elu,
     'LeakyRelu': convert_lrelu,
     'Sigmoid': convert_sigmoid,
@@ -74,5 +75,6 @@ AVAILABLE_CONVERTERS = {
     'Pad': convert_padding,
     'Flatten': convert_flatten,
     'Upsample': convert_upsample,
-    'Erf': convert_erf
+    'Erf': convert_erf,
+    'Reciprocal': convert_reciprocal
 }
