@@ -1,4 +1,5 @@
 from keras.layers import SlicingOpLambda
+from keras.layers.preprocessing.image_preprocessing import ResizeMethod
 from tensorflow import keras
 import tensorflow as tf
 import numpy as np
@@ -89,8 +90,20 @@ def convert_gather(node, params, layers, lambda_func, node_name, keras_name):
             raise AttributeError('Can\'t gather by axis more than 3.')
     else:
         input_0 = ensure_tf_type(layers[node.input[0]], layers[list(layers)[0]], name="%s_const" % keras_name)
-        indices = layers[node.input[1]].tolist()
-        layers[node_name] = tf.gather(input_0, indices, axis=params['axis'])
+        if not isinstance(layers[node.input[1]], np.ndarray) and \
+                tf.keras.backend.is_keras_tensor(layers[node.input[1]]):
+            indices = layers[node.input[1]]
+        else:
+            indices = layers[node.input[1]].tolist()
+        if "is_embedding" in params:
+            if len(input_0.shape) == 2:
+                emb = tf.keras.layers.Embedding(input_0.shape[0], input_0.shape[1], weights=[layers[node.input[0]]],
+                                                name=keras_name)
+                layers[node_name] = emb(indices)
+            else:
+                raise AttributeError("Cannot transform gather into embedding with non 2D array")
+        else:
+            layers[node_name] = tf.gather(input_0, indices, axis=params['axis'])
 
 
 def convert_concat(node, params, layers, lambda_func, node_name, keras_name):
@@ -193,8 +206,11 @@ def convert_reshape(node, params, layers, lambda_func, node_name, keras_name):
                     flatten = keras.layers.Flatten(name=keras_name)
                     layers[node_name] = flatten(input_0)
                 else:
-                    reshape = keras.layers.Reshape(np.int32(input_1[1:]), name=keras_name)
-                    layers[node_name] = reshape(input_0)
+                    if input_0.shape[0] != input_1[0]:  # keras reshape don't work
+                        layers[node_name] = tf.reshape(input_0, input_1, name=keras_name)
+                    else:
+                        reshape = keras.layers.Reshape(np.int32(input_1[1:]), name=keras_name)
+                        layers[node_name] = reshape(input_0)
     else:
         raise AttributeError('Can\'t reshape dynamic size.')
 
@@ -332,10 +348,7 @@ def convert_slice(node, params, layers, lambda_func, node_name, keras_name):
                     e[axis] = _e
                     mask = mask ^ (0x1 << axis)
                 return tf.strided_slice(x, s, e, begin_mask=mask, end_mask=mask)
-
-            lambda_layer = keras.layers.Lambda(target_layer, name=keras_name)
-            layers[node_name] = lambda_layer(input_0)
-            lambda_func[keras_name] = target_layer
+            layers[node_name] = target_layer(input_0)
         else:
             def target_layer(x, axis=axes, starts=starts, ends=ends):
                 import tensorflow as tf
@@ -372,10 +385,48 @@ def convert_squeeze(node, params, layers, lambda_func, node_name, keras_name):
     def target_layer(x, axis=params['axes'][0]):
         from tensorflow import keras
         return keras.backend.squeeze(x, axis)
+    layers[node_name] = target_layer(input_0)
 
-    lambda_layer = keras.layers.Lambda(target_layer, name=keras_name)
-    layers[node_name] = lambda_layer(input_0)
-    lambda_func[keras_name] = target_layer
+
+def convert_resize(node, params, layers, lambda_func, node_name, keras_name):
+    logger = logging.getLogger('onnx2keras.reshape')
+
+    input_tensor = layers[node.input[0]]
+    roi = layers[node.input[1]]
+    scales = layers[node.input[2]]
+    sizes = None
+    if len(node.input) == 4:
+        sizes = layers[node.input[3]]
+
+    if roi:
+        raise Exception("Resize with roi not supported")
+
+    if params['mode'] == b'nearest':
+        resize_method = ResizeMethod.NEAREST_NEIGHBOR
+    elif params['mode'] == b'cubic':
+        resize_method = ResizeMethod.BICUBIC
+    else:
+        raise Exception("unsupported resize method")
+
+
+    to_channel_last = keras.layers.Permute((2, 3, 1))(input_tensor)
+    if len(scales) > 0:
+        if scales[0] != 1 or scales[1] != 1:
+            raise Exception("Resize of channels or batch dim not suppported")
+
+        tf_resize_shapes = [int(scales[2] * to_channel_last.shape[1]),
+                            int(scales[3] * to_channel_last.shape[2])]
+    else:
+        if sizes[0] != 1 or sizes[1] != 1:
+            raise Exception("Resize of channels or batch dim not suppported")
+        tf_resize_shapes = [int(sizes[2]), int(sizes[3])]
+
+    resized = tf.image.resize(to_channel_last,
+                              size=[int(scales[2] * to_channel_last.shape[1]),
+                                    int(scales[3] * to_channel_last.shape[2])],
+                              method=resize_method)
+    to_channel_first = keras.layers.Permute((3, 1, 2))(resized)
+    layers[node_name] = to_channel_first
 
 
 def convert_expand(node, params, layers, lambda_func, node_name, keras_name):
